# Конфигурация

## Параметры времени выполнения

- `host`
- `port`
- `workers`

## Переменные среды

- `VYRO_ENV`
- `VYRO_SECRET_KEY`
- `VYRO_WORKERS`
- `VYRO_LOG_SAMPLE_INFO`
- `VYRO_LOG_SAMPLE_WARN`
- `VYRO_LOG_SAMPLE_ERROR`

Используйте `vyro doctor --strict` в CI для проверки готовности производства.